TableFunction

Struct TableFunction 

pub struct TableFunction { /* private fields */ }
A function that returns a queryable table

Implementations

Source

impl TableFunction

pub fn supports_pushdown(&self, supports: bool) -> &Self

Sets whether or not the given table function supports projection pushdown.

If this is set to true, the system will provide a list of all required columns in the init stage through the InitInfo::get_column_indices method. If this is set to false (the default), the system will expect all columns to be projected.

Arguments
  • pushdown: True if the table function supports projection pushdown, false otherwise.
pub fn add_parameter(&self, logical_type: &LogicalTypeHandle) -> &Self

Adds a parameter to the table function.

Arguments
  • logical_type: The type of the parameter to add.
pub fn add_named_parameter( &self, name: &str, logical_type: &LogicalTypeHandle, ) -> &Self

Adds a named parameter to the table function.

Arguments
  • name: The name of the parameter to add.
  • logical_type: The type of the parameter to add.
pub fn set_function( &self, func: Option<unsafe extern "C" fn(info: duckdb_function_info, output: duckdb_data_chunk)>, ) -> &Self

Sets the main function of the table function

Arguments
  • function: The function
pub fn set_init( &self, init_func: Option<unsafe extern "C" fn(duckdb_init_info)>, ) -> &Self

Sets the init function of the table function

Arguments
  • function: The init function
pub fn set_bind( &self, bind_func: Option<unsafe extern "C" fn(duckdb_bind_info)>, ) -> &Self

Sets the bind function of the table function

Arguments
  • function: The bind function
pub fn new() -> Self

Creates a new empty table function.

pub fn set_name(&self, name: &str) -> &Self

Sets the name of the given table function.

Arguments
  • name: The name of the table function
pub unsafe fn set_extra_info_raw( &self, extra_info: *mut c_void, destroy: duckdb_delete_callback_t, )

Assigns extra information to the table function using raw pointers.

For most use cases, prefer set_extra_info which handles memory management automatically.

Arguments
  • extra_info: The extra information as a raw pointer
  • destroy: The callback that will be called to destroy the data (if any)
Safety

The caller must ensure that extra_info is a valid pointer and that destroy properly cleans up the data when called.

pub fn set_extra_info<T>(&self, info: T) -> &Self
where T: Send + Sync + 'static,

Assigns extra information to the table function that can be fetched during binding, init, and execution.

Arguments
  • info: The extra information to store
pub fn set_local_init(&self, init: duckdb_table_function_init_t)

Sets the thread-local init function of the table function

Arguments
  • init: The init function