pub struct TableFunctionInfo<V: VTab> { /* private fields */ }Expand description
An interface to store and retrieve data during the function execution stage
Implementations
Sourceimpl<V: VTab> TableFunctionInfo<V>
impl<V: VTab> TableFunctionInfo<V>
Sourcepub fn get_bind_data(&self) -> &V::BindData
pub fn get_bind_data(&self) -> &V::BindData
Gets the bind data set by BindInfo::set_bind_data during the bind.
Note that the bind data should be considered as read-only. For tracking state, use the init data instead.
Sourcepub fn get_init_data(&self) -> &V::InitData
pub fn get_init_data(&self) -> &V::InitData
Get a reference to the init data set by InitInfo::set_init_data during the init.
This returns a shared reference because the init data is shared between multiple threads. It may internally be mutable.
Arguments
returns: The init data object
Sourcepub fn get_extra_info<T>(&self) -> *mut T
pub fn get_extra_info<T>(&self) -> *mut T
Retrieves the extra info of the function as set in TableFunction::set_extra_info.
Sourcepub fn get_local_init_data<T>(&self) -> *mut T
pub fn get_local_init_data<T>(&self) -> *mut T
Gets the thread-local init data set by InitInfo::set_init_data during the local_init.
Arguments
returns: The init data object